diff --git a/pidgin/gtkblist.c b/pidgin/gtkblist.c
--- a/pidgin/gtkblist.c
+++ b/pidgin/gtkblist.c
@@ -1584,14 +1584,14 @@
 		pidgin_append_blist_node_privacy_menu(menu, node);
 		pidgin_new_menu_item(menu, _("_Alias..."), PIDGIN_STOCK_ALIAS,
 				G_CALLBACK(gtk_blist_menu_alias_cb), contact);
-		pidgin_new_menu_item(menu, _("_Remove"), GTK_STOCK_REMOVE,
+		pidgin_new_menu_item(menu, _("_Remove"), NULL,
 				G_CALLBACK(pidgin_blist_remove_cb), contact);
 	} else if (!sub || contact_expanded) {
 		pidgin_separator(menu);
 		pidgin_append_blist_node_privacy_menu(menu, node);
 		pidgin_new_menu_item(menu, _("_Alias..."), PIDGIN_STOCK_ALIAS,
 				G_CALLBACK(gtk_blist_menu_alias_cb), buddy);
-		pidgin_new_menu_item(menu, _("_Remove"), GTK_STOCK_REMOVE,
+		pidgin_new_menu_item(menu, _("_Remove"), NULL,
 				G_CALLBACK(pidgin_blist_remove_cb), buddy);
 	}
 }
@@ -1737,13 +1737,13 @@
 	GtkWidget *item;
 
 	menu = gtk_menu_new();
-	item = pidgin_new_menu_item(menu, _("Add _Buddy..."), GTK_STOCK_ADD,
+	item = pidgin_new_menu_item(menu, _("Add _Buddy..."), NULL,
 				 G_CALLBACK(pidgin_blist_add_buddy_cb), node);
 	gtk_widget_set_sensitive(item, purple_connections_get_all() != NULL);
-	item = pidgin_new_menu_item(menu, _("Add C_hat..."), GTK_STOCK_ADD,
+	item = pidgin_new_menu_item(menu, _("Add C_hat..."), NULL,
 				 G_CALLBACK(pidgin_blist_add_chat_cb), node);
 	gtk_widget_set_sensitive(item, pidgin_blist_joinchat_is_showable());
-	pidgin_new_menu_item(menu, _("_Delete Group"), GTK_STOCK_REMOVE,
+	pidgin_new_menu_item(menu, _("_Delete Group"), NULL,
 				 G_CALLBACK(pidgin_blist_remove_cb), node);
 	pidgin_new_menu_item(menu, _("_Rename"), NULL,
 				 G_CALLBACK(gtk_blist_menu_alias_cb), node);
@@ -1789,7 +1789,7 @@
 				 G_CALLBACK(chat_components_edit), node);
 	pidgin_new_menu_item(menu, _("_Alias..."), PIDGIN_STOCK_ALIAS,
 				 G_CALLBACK(gtk_blist_menu_alias_cb), node);
-	pidgin_new_menu_item(menu, _("_Remove"), GTK_STOCK_REMOVE,
+	pidgin_new_menu_item(menu, _("_Remove"), NULL,
 				 G_CALLBACK(pidgin_blist_remove_cb), node);
 
 	add_buddy_icon_menu_items(menu, node);
@@ -1812,14 +1812,14 @@
 
 	pidgin_new_menu_item(menu, _("_Alias..."), PIDGIN_STOCK_ALIAS,
 				 G_CALLBACK(gtk_blist_menu_alias_cb), node);
-	pidgin_new_menu_item(menu, _("_Remove"), GTK_STOCK_REMOVE,
+	pidgin_new_menu_item(menu, _("_Remove"), NULL,
 				 G_CALLBACK(pidgin_blist_remove_cb), node);
 
 	add_buddy_icon_menu_items(menu, node);
 
 	pidgin_separator(menu);
 
-	pidgin_new_menu_item(menu, _("_Collapse"), GTK_STOCK_ZOOM_OUT,
+	pidgin_new_menu_item(menu, _("_Collapse"), NULL,
 				 G_CALLBACK(pidgin_blist_collapse_contact_cb),
 				 node);
 
@@ -1845,12 +1845,12 @@
 
 		if(gtknode->contact_expanded) {
 			pidgin_new_menu_item(menu, _("_Collapse"),
-                                        GTK_STOCK_ZOOM_OUT,
+                                        NULL,
                                         G_CALLBACK(pidgin_blist_collapse_contact_cb),
                                         node);
 		} else {
 			pidgin_new_menu_item(menu, _("_Expand"),
-                                        GTK_STOCK_ZOOM_IN,
+                                        NULL,
                                         G_CALLBACK(pidgin_blist_expand_contact_cb),
                                         node);
 		}
diff --git a/pidgin/gtkconv.c b/pidgin/gtkconv.c
--- a/pidgin/gtkconv.c
+++ b/pidgin/gtkconv.c
@@ -1045,12 +1045,12 @@
 	if (!is_me && protocol && !(purple_protocol_get_options(protocol) & OPT_PROTO_UNIQUE_CHATNAME) && PURPLE_PROTOCOL_IMPLEMENTS(protocol, SERVER, add_buddy)) {
 		if ((buddy = purple_blist_find_buddy(account, who)) != NULL)
 			button = pidgin_new_menu_item(menu, _("Remove"),
-                                        GTK_STOCK_REMOVE,
+                                        NULL,
                                         G_CALLBACK(menu_chat_add_remove_cb),
                                         PIDGIN_CONVERSATION(conv));
 		else
 			button = pidgin_new_menu_item(menu, _("Add"),
-                                        GTK_STOCK_ADD,
+                                        NULL,
                                         G_CALLBACK(menu_chat_add_remove_cb),
                                         PIDGIN_CONVERSATION(conv));
 
@@ -1702,7 +1702,7 @@
 	/* Conversation menu */
 	{ "ConversationMenu", NULL, N_("_Conversation"), NULL, NULL, NULL },
 	{ "ViewLog", NULL, N_("View _Log"), NULL, NULL, G_CALLBACK(menu_view_log_cb) },
-	{ "SaveAs", GTK_STOCK_SAVE_AS, N_("_Save As..."), NULL, NULL, G_CALLBACK(menu_save_as_cb) },
+	{ "SaveAs", NULL, N_("_Save As..."), NULL, NULL, G_CALLBACK(menu_save_as_cb) },
 
 #ifdef USE_VV
 	{ "MediaMenu", NULL, N_("M_edia"), NULL, NULL, NULL },
@@ -1719,11 +1719,11 @@
 	{ "Alias", NULL, N_("Al_ias..."), NULL, NULL, G_CALLBACK(menu_alias_cb) },
 	{ "Block", PIDGIN_STOCK_TOOLBAR_BLOCK, N_("_Block..."), NULL, NULL, G_CALLBACK(menu_block_cb) },
 	{ "Unblock", PIDGIN_STOCK_TOOLBAR_UNBLOCK, N_("_Unblock..."), NULL, NULL, G_CALLBACK(menu_unblock_cb) },
-	{ "Add", GTK_STOCK_ADD, N_("_Add..."), NULL, NULL, G_CALLBACK(menu_add_remove_cb) },
-	{ "Remove", GTK_STOCK_REMOVE, N_("_Remove..."), NULL, NULL, G_CALLBACK(menu_add_remove_cb) },
+	{ "Add", NULL, N_("_Add..."), NULL, NULL, G_CALLBACK(menu_add_remove_cb) },
+	{ "Remove", NULL, N_("_Remove..."), NULL, NULL, G_CALLBACK(menu_add_remove_cb) },
 	{ "InsertLink", PIDGIN_STOCK_TOOLBAR_INSERT_LINK, N_("Insert Lin_k..."), NULL, NULL, NULL },
 	{ "InsertImage", PIDGIN_STOCK_TOOLBAR_INSERT_IMAGE, N_("Insert Imag_e..."), NULL, NULL, NULL },
-	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W", NULL, G_CALLBACK(menu_close_conv_cb) },
+	{ "Close", NULL, N_("_Close"), "<control>W", NULL, G_CALLBACK(menu_close_conv_cb) },
 
 	/* Options */
 	{ "OptionsMenu", NULL, N_("_Options"), NULL, NULL, NULL },
diff --git a/pidgin/gtkstatusbox.c b/pidgin/gtkstatusbox.c
--- a/pidgin/gtkstatusbox.c
+++ b/pidgin/gtkstatusbox.c
@@ -172,7 +172,7 @@
 
 	/*
  	 * This column stores the GdkPixbuf for the status emblem. Currently only 'saved' is stored.
 	 * In the GtkTreeModel for the dropdown, this is the stock-id (gchararray), and for the
 	 * GtkTreeModel for the cell_view (for the account-specific statusbox), this is the protocol icon
 	 * (GdkPixbuf) of the account.
  	 */
@@ -1320,7 +1320,7 @@
 	gtk_tree_view_column_pack_start(status_box->column, emblem_rend, FALSE);
 	gtk_tree_view_column_set_attributes(status_box->column, icon_rend, "stock-id", ICON_STOCK_COLUMN, NULL);
 	gtk_tree_view_column_set_attributes(status_box->column, text_rend, "markup", TEXT_COLUMN, NULL);
-	gtk_tree_view_column_set_attributes(status_box->column, emblem_rend, "stock-id", EMBLEM_COLUMN, "visible", EMBLEM_VISIBLE_COLUMN, NULL);
+	gtk_tree_view_column_set_attributes(status_box->column, emblem_rend, "icon-name", EMBLEM_COLUMN, "visible", EMBLEM_VISIBLE_COLUMN, NULL);
 
 	status_box->scrolled_window = pidgin_make_scrollable(status_box->tree_view, GTK_POLICY_NEVER, GTK_POLICY_NEVER, GTK_SHADOW_NONE, -1, -1);
 	gtk_container_add (GTK_CONTAINER (status_box->popup_frame),
@@ -1584,7 +1584,7 @@
 			DESC_COLUMN, desc,
 			DATA_COLUMN, data,
 			EMBLEM_VISIBLE_COLUMN, type == PIDGIN_STATUS_BOX_TYPE_SAVED_POPULAR,
-			EMBLEM_COLUMN, GTK_STOCK_SAVE,
+			EMBLEM_COLUMN, "document-save",
 			-1);
 	g_free(text);
 }
@@ -172,7 +172,7 @@
 	/*
  	 * This column stores the GdkPixbuf for the status emblem. Currently only 'saved' is stored.
-	 * In the GtkTreeModel for the dropdown, this is the stock-id (gchararray), and for the
+	 * In the GtkTreeModel for the dropdown, this is the icon-name (gchararray), and for the
 	 * GtkTreeModel for the cell_view (for the account-specific statusbox), this is the protocol icon
 	 * (GdkPixbuf) of the account.
